summaryrefslogtreecommitdiffstats
path: root/chromeos
diff options
context:
space:
mode:
authorachuith <achuith@chromium.org>2015-04-29 16:21:55 -0700
committerCommit bot <commit-bot@chromium.org>2015-04-29 23:22:28 +0000
commitc73fce65a5963c8013e8a0a2b0251ba7c02bfccc (patch)
tree907c52572aa3868a36b5eb596867a03390c1bfe3 /chromeos
parent3b678eae31007c956a67f507172be4f287725c95 (diff)
downloadchromium_src-c73fce65a5963c8013e8a0a2b0251ba7c02bfccc.zip
chromium_src-c73fce65a5963c8013e8a0a2b0251ba7c02bfccc.tar.gz
chromium_src-c73fce65a5963c8013e8a0a2b0251ba7c02bfccc.tar.bz2
Revert of Revert "Enable BlockingLoginTest, ForceMaximizeOnFirstRunTest, UserCloudPolicyManagerTest, for webv… (patchset #1 id:1 of https://codereview.chromium.org/1109393005/)
Reason for revert: This was a speculative revert, but I don't believe the browser tests reverted here were the cause of the blink failures. Original issue's description: > Revert "Enable BlockingLoginTest, ForceMaximizeOnFirstRunTest, UserCloudPolicyManagerTest, for webview." > > This reverts commit 8c52ec023857ec7d082d54518864edd84d25b116. > > This seems to be breaking "Linux ChromiumOS Tests (dbg)" on the Blink waterfall, and blocking the Blink roll: > http://build.chromium.org/p/chromium.webkit/builders/Linux%20ChromiumOS%20Tests%20%28dbg%29%281%29/builds/1485 > > TBR=achuith,nkostylev@chromium.org > BUG= > NOTREECHECKS=true > > Committed: https://crrev.com/a5080f268e879b41a34a3f912fb5dabfc6b7a2dd > Cr-Commit-Position: refs/heads/master@{#327552} TBR=nkostylev@chromium.org,macourteau@chromium.org,senorblanco@chromium.org BUG=475567,477402 Review URL: https://codereview.chromium.org/1111593006 Cr-Commit-Position: refs/heads/master@{#327611}
Diffstat (limited to 'chromeos')
-rw-r--r--chromeos/login/auth/auth_status_consumer.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/chromeos/login/auth/auth_status_consumer.h b/chromeos/login/auth/auth_status_consumer.h
index e7e3bda..ad202a5 100644
--- a/chromeos/login/auth/auth_status_consumer.h
+++ b/chromeos/login/auth/auth_status_consumer.h
@@ -29,15 +29,14 @@ class CHROMEOS_EXPORT AuthFailure {
UNLOCK_FAILED,
NETWORK_AUTH_FAILED, // Could not authenticate against Google
OWNER_REQUIRED, // Only the device owner can log-in.
- WHITELIST_CHECK_FAILED, // Login attempt blocked by whitelist. This value
- // is
- // synthesized by the ExistingUserController and
- // passed to the login_status_consumer_ in tests
- // only. It is never generated or seen by any of the
- // other authenticator classes.
- TPM_ERROR, // Critical TPM error encountered.
- USERNAME_HASH_FAILED, // Could not get username hash.
- NUM_FAILURE_REASONS, // This has to be the last item.
+ WHITELIST_CHECK_FAILED, // Login attempt blocked by whitelist. This
+ // value is synthesized by the ExistingUserController and passed to the
+ // login_status_consumer_ in tests only. It is never generated or seen by
+ // any of the other authenticator classes.
+ TPM_ERROR, // Critical TPM error encountered.
+ USERNAME_HASH_FAILED, // Could not get username hash.
+ FAILED_TO_INITIALIZE_TOKEN, // Could not get OAuth2 Token,
+ NUM_FAILURE_REASONS, // This has to be the last item.
};
explicit AuthFailure(FailureReason reason)
@@ -85,6 +84,8 @@ class CHROMEOS_EXPORT AuthFailure {
return "Login is restricted to the owner's account only.";
case WHITELIST_CHECK_FAILED:
return "Login attempt blocked by whitelist.";
+ case FAILED_TO_INITIALIZE_TOKEN:
+ return "OAuth2 token fetch failed.";
default:
NOTREACHED();
return std::string();